%Reading the input audio data
infile = 'voz1.wav' ;
% Name of the Input file
[x, Fs, bits]=wavread(infile);
%
sound(x,Fs);
%Plotting the input signal
plot([1:length(x)]/1000,128*x) ;
title ('original speech signal')
xlabel('Samples (x1000)');  ylabel('Sample Values');
print -dtiff plot.tiff
pause;
%
%Calculating Power spectral density
hann_wind = round(2048*0.8) ;
[Px,F] = psd(x,2048,Fs,[],hann_wind); % power spectral density of the input signal
plot(F/1000,10*log10(Px))
xlabel('Frequency (in KHz)'); ylabel('Power Spectral Density (in dB)');
print -dtiff plot.tiff
pause;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Filtering (Type 1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lcutoff = 4000 ;  % cutoff frequency in Hz
wp = lcutoff/(Fs/2) ;  % Normalized cutoff
filt_low = fir1(64,wp) ;
%Plotting the LPF frequency characteristics
[L, w] = freqz(filt_low,1,512);
LdB = 20*log10(abs(L)) ;
plot((w/pi)*(Fs/2000), LdB), grid
xlabel('Frequency  (in KHz)')
ylabel('Filter Gain (in dB)');
print -dtiff plot.tiff
% Filtering the audio signal
x_lpf = filter(filt_low,1,x) ;
x_lpf=x_lpf./max(0.1,max(abs(x_lpf))) ;             % scale up the output
wavwrite(x_lpf,Fs,8,'voz1_lpf.wav');               % Write the output signal as a wav file
%
sound(x_lpf,Fs);
pause;
%Calculating Power spectral density
hann_wind = round(1024*0.8) ;
[Px_lpf,F] = psd(x_lpf,1024,Fs,[],hann_wind); % power spectral density of the output
plot(F/1000,10*log10(Px_lpf))
xlabel('Frequency (in KHz)'); ylabel('PSD (in dB)');
print -dtiff plot.tiff
%
